<h1 align="center"> Gitscrpy </h1>

***

<p align="center">
•
    <a href="#install">Install</a>
    •
   <a href="">Run</a>
    •
    <a href="">Contribute</a>
</p>

* `A python library to scrape github.`
* `Simple to use syntax`
* `Install using pip`

<h3 id="install">Install</h3>

```python
pip install gitscrpy


```

